%------------------------------------------------------------------------------------------------
% calculate mean Inter-variability across 2 runs on fsaverage4 (2562 vertices on each hemisphere)
% 2019,09,04 update
%------------------------------------------------------------------------------------------------

clear,clc,close all

SIDs = textread(['/autofs/space/bidlin11_003/users/sleep_data/Lists/Sleep_List_TwoBold.txt'],'%s');
OUT_DIR=(['/autofs/space/bidlin11_003/users/sleep_data/Results/Variability']);


%% 1. Load FC from different runs

paths = {['/autofs/space/bidlin11_003/users/sleep_data/Results/Corr_results_test'];...
         ['/autofs/space/bidlin11_003/users/sleep_data/Results/Corr_results_retest'];};


  %% load file to extract vertices on cortex (not in midline)
LV = textread('/autofs/space/bidlin11_001/users/Share/Templates/Surf/fsaverage4/label/lh.cortex.label', '','headerlines',2);
RV = textread('/autofs/space/bidlin11_001/users/Share/Templates/Surf/fsaverage4/label/rh.cortex.label', '','headerlines',2);
cortex_left = LV(:,1)+1;
cortex_right = RV(:,1)+1; 
cortex = [cortex_left;cortex_right+2562];


    
runlist = ['A','B'];
runnum = length(runlist);

CC_Big_Allruns = zeros(length(SIDs),runnum,length(cortex),length(cortex));

for s=1:length(SIDs)  % for each subject   
    s 
    subname = SIDs{s};   
    for run_i = 1:runnum
        path = paths{run_i};
        
        load([path,'/CECE_', subname, '_lh_to_lh.mat']);
        LL_corr=corr_mat;

        load([path,'/CECE_', subname, '_lh_to_rh.mat']);
        LR_corr=corr_mat;

        load([path,'/CECE_', subname, '_rh_to_lh.mat']);
        RL_corr=corr_mat;

        load([path,'/CECE_', subname, '_rh_to_rh.mat']);
        RR_corr=corr_mat;

        CC=[LL_corr LR_corr; RL_corr RR_corr];
        CC = CC(cortex,cortex);

        
        CC_Big_Allruns(s,run_i,:,:)=CC;
    end  
end

% ---------------------------------------------------
%% 2. Find between-subject variance for each run
% --------------------------------------------------


for run_i = 1:runnum
    session_name = runlist(run_i); % runs
    for s1 = 1:length(SIDs)
        s1
        CC_Big1 = squeeze(CC_Big_Allruns(s1,run_i,:,:));
        for s2 = 1:length(SIDs)
            CC_Big2 = squeeze(CC_Big_Allruns(s2,run_i,:,:));
            Variability(s1,s2,:) = 1-my_matcorr(CC_Big1,CC_Big2);
        end
    end
    
    mean_Variability = squeeze(mean(mean(Variability,1),2));


    Map = zeros(1,5124);Map(cortex) = mean_Variability;
    save_mgh(Map(1:2562),[OUT_DIR,'/LH_mean_Inter',session_name,'_Variability.mgh'], eye(4));
    save_mgh(Map(2562+1:end),[OUT_DIR,'/RH_mean_Inter',session_name,'_Variability.mgh'], eye(4));


    %-----------------------------------------------------------
    %%  3. LH inter-individual variability - intra- regression
    %------------------------------------------------------------

    x = load_mgh([OUT_DIR '/LH_mean_Intra_Variability.mgh']);
    y = load_mgh([OUT_DIR '/LH_mean_Inter' session_name '_Variability.mgh']);
    x = x(cortex_left);y = y(cortex_left);
    x = bsxfun(@minus, x, mean(x));
   

    % Regression
    ord = randperm(length(cortex_left)); %%shuffle vertices to get rid of spatial correlation
    x = x(ord);
    y = y(ord);
    [n, revOrd]= sort(ord); %% create re-sorting vector

    [b,dev,stats] = glmfit(x,y); %% regression
    con=b(1); %constsant term
    resid=stats.resid;
    trueResid=resid(revOrd); %%re-sort in correct order
    residuals=trueResid+con; %% add back constant term
    
    Map = zeros(1,2562);Map(cortex_left) = residuals;
    save_mgh(Map,[OUT_DIR,'/LH_Inter',session_name,'_Intraregressed_out.mgh'], eye(4));

    
    %-----------------------------------------------------------
    %%  3. RH inter-individual variability - intra- regression
    %------------------------------------------------------------

    x = load_mgh([OUT_DIR '/RH_mean_Intra_Variability.mgh']);
    y = load_mgh([OUT_DIR '/RH_mean_Inter' session_name '_Variability.mgh']);
    x = x(cortex_right);y = y(cortex_right);
    x = bsxfun(@minus, x, mean(x));
    
 

    % Regression
    ord = randperm(length(cortex_right)); %%shuffle vertices to get rid of spatial correlation
    x = x(ord); 
    y = y(ord);
    [n, revOrd]= sort(ord); %% create re-sorting vector

    [b,dev,stats] = glmfit(x,y); %% regression
    con=b(1); %constsant term
    resid=stats.resid;
    trueResid=resid(revOrd); %%re-sort in correct order

    residuals=trueResid+con; %% add back constant term
    Map = zeros(1,2562);Map(cortex_right) = residuals;
    save_mgh(Map,[OUT_DIR,'/RH_Inter',session_name,'_Intraregressed_out.mgh'], eye(4));
    
end

%-------------------------------------------------------------------
%% 4. Calculate mean Inter_Intra_regressed_out across multiple runs
%--------------------------------------------------------------------

Big_LH_mean_Multiregressions=zeros(length(runlist), 2562);
Big_RH_mean_Multiregressions=zeros(length(runlist), 2562);

for s = 1:length(runlist)
    session_name = runlist(s);
    vol = load_mgh([OUT_DIR '/LH_Inter' session_name '_Intraregressed_out.mgh']);
    Big_LH_mean_Multiregressions(s,:)=vol;
    
    vol = load_mgh([OUT_DIR '/RH_Inter' session_name '_Intraregressed_out.mgh']);
    Big_RH_mean_Multiregressions(s,:)=vol;
end

regression_allruns = mean(Big_LH_mean_Multiregressions, 1);
save_mgh(regression_allruns,[OUT_DIR,'/LH_mean_of_' num2str(runnum) 'inter_intra_regressed_out.mgh'], eye(4));

z_regression_allruns=zscore(regression_allruns(cortex_left));
Map = zeros(1,2562);Map(cortex_left) = z_regression_allruns;
save_mgh(Map,[OUT_DIR,'/z_LH_mean_of_' num2str(runnum) 'inter_intra_regressed_out.mgh'], eye(4));

regression_allruns = mean(Big_RH_mean_Multiregressions, 1);
save_mgh(regression_allruns, [OUT_DIR,'/RH_mean_of_' num2str(runnum) 'inter_intra_regressed_out.mgh'], eye(4));

z_regression_allruns=zscore(regression_allruns(cortex_right));
Map = zeros(1,2562);Map(cortex_right) = z_regression_allruns;
save_mgh(Map, [OUT_DIR,'/z_RH_mean_of_' num2str(runnum) 'inter_intra_regressed_out.mgh'], eye(4));


